==> vacuum-1.0.1-source.tar.gz: vacuum-1.0.1/src/translations/ru_RU/clientinfo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU" sourcelanguage="en">
<context>
    <name>ClientInfo</name>
    <message>
        <source>Software version</source>
        <translation>Версия приложения</translation>
    </message>
    <message>
        <source>Last activity</source>
        <translation>Последняя активность</translation>
    </message>
    <message>
        <source>Entity time</source>
        <translation>Время контакта</translation>
    </message>
    <message>
        <source>Software: %1 %2</source>
        <translation>Приложение: %1 %2</translation>
    </message>
    <message>
        <source>Offline since: %1</source>
        <translation>Отключен с: %1</translation>
    </message>
    <message>
        <source>Entity time: %1</source>
        <translation>Время контакта: %1</translation>
    </message>
    <message>
        <source>Software information</source>
        <translation>Информация о приложении</translation>
    </message>
    <message>
        <source>Software</source>
        <translation>Приложение</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation>Версия приложения</translation>
    </message>
    <message>
        <source>OS</source>
        <translation>ОС</translation>
    </message>
    <message>
        <source>OS Version</source>
        <translation>Версия ОС</translation>
    </message>
    <message>
        <source>Client Information</source>
        <translation>Клиентская информация</translation>
    </message>
    <message>
        <source>Allows to send and receive information about the version of the application, the local time and the last activity of contact</source>
        <translation>Позволяет отправлять и получать информацию о версии приложения, локальном времени и последней активности контакта</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the application version</source>
        <translation>Поддерживает обмен информацией о версии приложения</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation>Последняя активность</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user last activity</source>
        <translation>Поддерживает обмен информацией о последней активности пользователя</translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation>Время контакта</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user local time</source>
        <translation>Поддерживает обмен информацией о локальном времени пользователя</translation>
    </message>
</context>
<context>
    <name>ClientInfoDialog</name>
    <message>
        <source>Client info - %1</source>
        <translation>Информация о клиенте - %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Software Version&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;b&gt;Версия приложения&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Версия:</translation>
    </message>
    <message>
        <source>OS:</source>
        <translation>ОС:</translation>
    </message>
    <message>
        <source>Error:</source>
        <translation>Ошибка:</translation>
    </message>
    <message>
        <source>Not loaded&lt;br&gt;</source>
        <translation>Не удалось загрузить&lt;br&gt;</translation>
    </message>
    <message>
        <source>Loading ...&lt;br&gt;</source>
        <translation>Загружается...&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Last Activity&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;b&gt;Последняя активность&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Дата:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Статус:</translation>
    </message>
    <message>
        <source>&lt;b&gt;Entity time&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;b&gt;Локальное время контакта&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Время:</translation>
    </message>
    <message>
        <source>Delta:</source>
        <translation>Разность:</translation>
    </message>
    <message>
        <source>Ping, msec:</source>
        <translation>Пинг, мсек:</translation>
    </message>
    <message>
        <source>Not available&lt;br&gt;</source>
        <translation>Недоступно&lt;br&gt;</translation>
    </message>
    <message>
        <source>%1y </source>
        <translation>%1г</translation>
    </message>
    <message>
        <source>%1d </source>
        <translation>%1д</translation>
    </message>
    <message>
        <source>%1h </source>
        <translation>%1ч</translation>
    </message>
    <message>
        <source>%1m </source>
        <translation>%1м</translation>
    </message>
    <message>
        <source>%1s</source>
        <translation>%1с</translation>
    </message>
</context>
<context>
    <name>MiscOptionsWidgetClass</name>
    <message>
        <source>Share information about OS version</source>
        <translation>Раскрывать информацию о версии ОС</translation>
    </message>
</context>
</TS>

==> vacuum-1.0.2-source.tar.gz: vacuum-1.0.2/src/translations/ru_RU/clientinfo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU" sourcelanguage="en">
<context>
    <name>ClientInfo</name>
    <message>
        <source>Software: %1 %2</source>
        <translation>Приложение: %1 %2</translation>
    </message>
    <message>
        <source>Entity time: %1</source>
        <translation>Время контакта: %1</translation>
    </message>
    <message>
        <source>Software information</source>
        <translation>Информация о приложении</translation>
    </message>
    <message>
        <source>Software</source>
        <translation>Приложение</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation>Версия приложения</translation>
    </message>
    <message>
        <source>OS</source>
        <translation>ОС</translation>
    </message>
    <message>
        <source>OS Version</source>
        <translation>Версия ОС</translation>
    </message>
    <message>
        <source>Client Information</source>
        <translation>Клиентская информация</translation>
    </message>
    <message>
        <source>Allows to send and receive information about the version of the application, the local time and the last activity of contact</source>
        <translation>Позволяет отправлять и получать информацию о версии приложения, локальном времени и последней активности контакта</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the application version</source>
        <translation>Поддерживает обмен информацией о версии приложения</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation>Последняя активность</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user last activity</source>
        <translation>Поддерживает обмен информацией о последней активности пользователя</translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation>Время контакта</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user local time</source>
        <translation>Поддерживает обмен информацией о локальном времени пользователя</translation>
    </message>
    <message>
        <source>Service Uptime</source>
        <translation>Время работы сервиса</translation>
    </message>
    <message>
        <source>Idle Time</source>
        <translation>Время бездействия</translation>
    </message>
</context>
<context>
    <name>ClientInfoDialog</name>
    <message>
        <source>Client info - %1</source>
        <translation>Информация о клиенте - %1</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Версия:</translation>
    </message>
    <message>
        <source>OS:</source>
        <translation>ОС:</translation>
    </message>
    <message>
        <source>Error:</source>
        <translation>Ошибка:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Статус:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Время:</translation>
    </message>
    <message>
        <source>Delta:</source>
        <translation>Разность:</translation>
    </message>
    <message>
        <source>Ping, msec:</source>
        <translation>Пинг, мсек:</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation>Версия приложения</translation>
    </message>
    <message>
        <source>Service Uptime</source>
        <translation>Время работы сервиса</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation>Последняя активность</translation>
    </message>
    <message>
        <source>Idle Time</source>
        <translation>Время бездействия</translation>
    </message>
    <message>
        <source>Uptime:</source>
        <translation>Работает:</translation>
    </message>
    <message>
        <source>Inactive:</source>
        <translation>Не активен:</translation>
    </message>
    <message>
        <source>Idle:</source>
        <translation>Бездействует:</translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation>Время контакта</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Не доступно</translation>
    </message>
    <message>
        <source>%1y</source>
        <comment>years</comment>
        <translation>%1г</translation>
    </message>
    <message>
        <source>%1d</source>
        <comment>days</comment>
        <translation>%1д</translation>
    </message>
    <message>
        <source>%1h</source>
        <comment>hours</comment>
        <translation>%1ч</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>minutes</comment>
        <translation>%1м</translation>
    </message>
    <message>
        <source>%1s</source>
        <comment>seconds</comment>
        <translation>%1с</translation>
    </message>
    <message>
        <source>Waiting response...</source>
        <translation>Ожидание ответа...</translation>
    </message>
</context>
<context>
    <name>MiscOptionsWidgetClass</name>
    <message>
        <source>Share information about OS version</source>
        <translation>Раскрывать информацию о версии ОС</translation>
    </message>
</context>
</TS>
